@@ -1,5 +1,5 @@
 <?php
-//VERSION=0.2
+//VERSION=0.3
 //https://docs.phpmyadmin.net/en/latest/setup.html#signon-authentication-mode
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
@@ -28,7 +28,7 @@ session_name($session_name);
 @session_start();
 
 
-if (isset($_POST['token']))
+if (isset($_POST['token']) || isset($_GET['token']))
 {
 	$info = get_token_info();
 
@@ -45,9 +45,12 @@ if (isset($_POST['token']))
 
 	if (isset($_POST['logout_url']) && $_POST['logout_url'] != '')
 		$_SESSION['logout_url'] = $_POST['logout_url'];
+	else
+	if (isset($_GET['logout_url']) && $_GET['logout_url'] != '')
+		$_SESSION['logout_url'] = $_GET['logout_url'];
 
 	/* Update another field of server configuration */
-	$_SESSION['PMA_single_signon_cfgupdate'] = ['verbose' => 'Signon test'];
+	$_SESSION['PMA_single_signon_cfgupdate'] = ['verbose' => 'DA PMA Signon'];
 	$id = session_id();
 
 	/* Close that session */
@@ -68,9 +71,16 @@ function die_rm($str, $file) {
 	die_error($str);
 }
 function get_token_info() {
-	if (!isset($_POST['token']) || !valid_token($_POST['token']))
-			die_error('Invalid token');
-	$token = $_POST['token'];
+	if (!isset($_POST['token']) && !isset($_GET['token']))
+		die_error('Missing token');
+
+	if (isset($_POST['token']))
+		$token = $_POST['token'];
+	else
+		$token = $_GET['token'];
+	if (!valid_token($token))
+		die_error('Invalid token');
+
 	$dir = dirname($_SERVER['SCRIPT_FILENAME']);
 	$token_file = $dir.'/tokens/'.$token;
 	if (!file_exists($token_file))
